@@ -96,7 +96,7 @@ class Quik:
             else:
                 fee = fee + float(row[self.FeeEx1]) + float(row[self.FeeEx2]) + float(row[self.FeeEx3])
             bond_interest = float(row[self.Coupon])
-            JalDB().add_trade(account_id, asset_id, timestamp, settlement, number, qty, price, -fee)
+            JalDB().add_trade(account_id, asset_id, timestamp, settlement, number, qty, price, fee)
             if bond_interest != 0:
                 JalDB().add_dividend(DividendSubtype.BondInterest, timestamp, account_id, asset_id,
                                      bond_interest, "НКД", number)
