@@ -4,8 +4,8 @@ from PySide2.QtWidgets import QApplication, QDialog
 from PySide2.QtSql import QSqlTableModel
 
 from jal.ui.ui_add_asset_dlg import Ui_AddAssetDialog
-from jal.constants import Setup
-from jal.db.helpers import db_connection, executeSQL, readSQL
+from jal.constants import Setup, PredefindedAccountType
+from jal.db.helpers import db_connection, executeSQL, readSQL, get_country_by_code
 from jal.widgets.helpers import g_tr
 
 
@@ -67,6 +67,9 @@ class JalDB():
     def get_asset_name(self, asset_id):
         return readSQL("SELECT name FROM assets WHERE id=:asset_id", [(":asset_id", asset_id)])
 
+    def get_asset_type(self, asset_id):
+        return readSQL("SELECT type_id FROM assets WHERE id=:asset_id", [(":asset_id", asset_id)])
+
     def get_account_name(self, account_id):
         return readSQL("SELECT name FROM accounts WHERE id=:account_id", [(":account_id", account_id)])
 
@@ -84,13 +87,54 @@ class JalDB():
                                  "LEFT JOIN assets AS c ON c.id=a.currency_id "
                                  "WHERE a.number=:account_number", [(":account_number", accountNumber)],
                                  check_unique=True)
-        if account_id is None:
-            logging.error(g_tr('JalDB', "Account not found: ") + f"{accountNumber} ({accountCurrency})")
         return account_id
 
+    def find_account(self, account_number, currency_code):
+        return readSQL("SELECT id FROM accounts WHERE number=:account_number AND currency_id=:currency",
+                       [(":account_number", account_number), (":currency", currency_code)], check_unique=True)
+
+    def add_account(self, account_number, currency_code, account_type=PredefindedAccountType.Investment):
+        account_id = self.find_account(account_number, currency_code)
+        if account_id:  # Account already exists
+            logging.warning(g_tr('JalDB', "Account already exists: ") +
+                            f"{account_number} ({self.get_asset_name(currency_code)})")
+            return account_id
+        currency = self.get_asset_name(currency_code)
+        account_info = readSQL(
+            "SELECT a.name AS name, SUBSTR(a.name, 1, LENGTH(a.name)-LENGTH(c.name)-1) AS short_name, "
+            "SUBSTR(a.name, -(LENGTH(c.name)+1), LENGTH(c.name)+1) = '.'||c.name AS auto_name "
+            "FROM accounts AS a LEFT JOIN assets AS c ON a.currency_id = c.id WHERE number=:account_number LIMIT 1",
+            [(":account_number", account_number)], named=True)
+        if account_info:  # Account with the same number but different currency exists
+            if account_info['auto_name']:
+                new_name = account_info['short_name'] + '.' + currency
+            else:
+                new_name = account_info['name'] + '.' + currency
+            query = executeSQL(
+                "INSERT INTO accounts (type_id, name, active, number, currency_id, organization_id, country_id) "
+                "SELECT a.type_id, :new_name, a.active, a.number, :currency_id, a.organization_id, a.country_id "
+                "FROM accounts AS a LEFT JOIN assets AS c ON c.id=:currency_id "
+                "WHERE number=:account_number LIMIT 1",
+                [(":account_number", account_number), (":currency_id", currency_code), (":new_name", new_name)])
+            return query.lastInsertId()
+
+        bank_name = g_tr('JalB', "Bank for #" + account_number)
+        bank_id = readSQL("SELECT id FROM agents WHERE name=:bank_name", [(":bank_name", bank_name)])
+        if bank_id is None:
+            query = executeSQL("INSERT INTO agents (pid, name) VALUES (0, :bank_name)", [(":bank_name", bank_name)])
+            bank_id = query.lastInsertId()
+        query = executeSQL("INSERT INTO accounts (type_id, name, active, number, currency_id, organization_id) "
+                           "VALUES(:type, :name, 1, :number, :currency, :bank)",
+                           [(":type", account_type), (":name", account_number+'.'+currency),
+                            (":number", account_number), (":currency", currency_code), (":bank", bank_id)])
+        return query.lastInsertId()
+
     def get_account_currency(self, account_id):
         return readSQL("SELECT currency_id FROM accounts WHERE id=:account_id", [(":account_id", account_id)])
 
+    def get_account_bank(self, account_id):
+        return readSQL("SELECT organization_id FROM accounts WHERE id=:account_id", [(":account_id", account_id)])
+
     # Searches for asset_id in database - first by ISIN, then by Reg.Code next by Symbol
     # If found - tries to update data if some is empty in database
     # If asset not found and 'dialog_new' is True - pops up a window for asset creation
@@ -102,29 +146,21 @@ class JalDB():
             if asset_id is None:
                 asset_id = readSQL("SELECT id FROM assets WHERE name=:symbol COLLATE NOCASE AND coalesce(isin, '')=''",
                                    [(":symbol", symbol)])
-        else:
+        if asset_id is None:
             if reg_code:
                 asset_id = readSQL("SELECT asset_id FROM asset_reg_id WHERE reg_code=:reg_code",
                                    [(":reg_code", reg_code)])
             if asset_id is None:
                 asset_id = readSQL("SELECT id FROM assets WHERE name=:symbol COLLATE NOCASE", [(":symbol", symbol)])
         if asset_id is not None:
-            self.update_asset_data(asset_id, symbol, isin, reg_code)
-        elif dialog_new:
+            self.update_asset_data(asset_id, symbol, isin, reg_code)   # FIXME move it outside this method
+            return asset_id
+        if asset_id is None and dialog_new:
             dialog = AddAssetDialog(symbol, isin=isin, name=name)
             dialog.exec_()
             asset_id = dialog.asset_id
         return asset_id
 
-    # Find asset by give partial name and type. Returns only first match even if many were found
-    def find_asset_like_name(self, partial_name, asset_type=0):
-        name = '%' + partial_name.replace(' ', '%') + '%'
-        if asset_type:
-            return readSQL("SELECT id FROM assets WHERE full_name LIKE :name AND type_id=:type",
-                           [(":name", name), (":type", asset_type)])
-        else:
-            return readSQL("SELECT id FROM assets WHERE full_name LIKE :name", [(":name", name)])
-
     def update_asset_data(self, asset_id, new_symbol='', new_isin='', new_reg=''):
         if new_symbol:
             symbol = readSQL("SELECT name FROM assets WHERE id=:asset_id", [(":asset_id", asset_id)])
@@ -168,14 +204,18 @@ class JalDB():
                      f"{self.get_asset_name(asset_id)} " 
                      f"@ {datetime.utcfromtimestamp(timestamp).strftime('%d/%m/%Y %H:%M:%S')} = {quote}")
 
-    def add_asset(self, symbol, name, asset_type, isin, data_source=-1):
-        query = executeSQL("INSERT INTO assets(name, type_id, full_name, isin, src_id) "
-                       "VALUES(:symbol, :type, :full_name, :isin, :data_src)",
-                       [(":symbol", symbol), (":type", asset_type), (":full_name", name),
-                        (":isin", isin), (":data_src", data_source)], commit=True)
+    def add_asset(self, symbol, name, asset_type, isin, data_source=-1, reg_code=None, country_code=''):
+        country_id = get_country_by_code(country_code)
+        query = executeSQL("INSERT INTO assets(name, type_id, full_name, isin, src_id, country_id) "
+                           "VALUES(:symbol, :type, :full_name, :isin, :data_src, :country_id)",
+                           [(":symbol", symbol), (":type", asset_type), (":full_name", name),
+                            (":isin", isin), (":data_src", data_source), (":country_id", country_id)], commit=True)
         asset_id = query.lastInsertId()
         if asset_id is None:
             logging.error(g_tr('JalDB', "Failed to add new asset: ") + f"{symbol}")
+        if reg_code is not None:
+            _ = executeSQL("INSERT INTO asset_reg_id(asset_id, reg_code) VALUES(:asset_id, :new_reg)",
+                           [(":new_reg", reg_code), (":asset_id", asset_id)])
         return asset_id
 
     def add_dividend(self, subtype, timestamp, account_id, asset_id, amount, note, trade_number='', tax=0.0):
@@ -193,7 +233,11 @@ class JalDB():
                         (":tax", tax), (":note", note)],
                        commit=True)
 
-    def add_trade(self, account_id, asset_id, timestamp, settlement, number, qty, price, fee):
+    def update_dividend_tax(self, dividend_id, new_tax):
+        _ = executeSQL("UPDATE dividends SET tax=:tax WHERE id=:dividend_id",
+                       [(":dividend_id", dividend_id), (":tax", new_tax)], commit=True)
+
+    def add_trade(self, account_id, asset_id, timestamp, settlement, number, qty, price, fee, note=''):
         trade_id = readSQL("SELECT id FROM trades "
                            "WHERE timestamp=:timestamp AND asset_id = :asset "
                            "AND account_id = :account AND number = :number AND qty = :qty AND price = :price",
@@ -203,11 +247,11 @@ class JalDB():
             logging.info(g_tr('JalDB', "Trade already exists: #") + f"{number}")
             return
 
-        _ = executeSQL("INSERT INTO trades (timestamp, settlement, number, account_id, asset_id, qty, price, fee) "
-                       "VALUES (:timestamp, :settlement, :number, :account, :asset, :qty, :price, :fee)",
+        _ = executeSQL("INSERT INTO trades (timestamp, settlement, number, account_id, asset_id, qty, price, fee, note)"
+                       " VALUES (:timestamp, :settlement, :number, :account, :asset, :qty, :price, :fee, :note)",
                        [(":timestamp", timestamp), (":settlement", settlement), (":number", number),
                         (":account", account_id), (":asset", asset_id), (":qty", float(qty)),
-                        (":price", float(price)), (":fee", -float(fee))], commit=True)
+                        (":price", float(price)), (":fee", float(fee)), (":note", note)], commit=True)
 
     def del_trade(self, account_id, asset_id, timestamp, _settlement, number, qty, price, _fee):
         _ = executeSQL("DELETE FROM trades "
@@ -218,8 +262,10 @@ class JalDB():
 
     def add_transfer(self, timestamp, f_acc_id, f_amount, t_acc_id, t_amount, fee_acc_id, fee, note):
         transfer_id = readSQL("SELECT id FROM transfers WHERE withdrawal_timestamp=:timestamp "
-                              "AND withdrawal_account=:from_acc_id AND deposit_account=:to_acc_id",
-                              [(":timestamp", timestamp), (":from_acc_id", f_acc_id), (":to_acc_id", t_acc_id)])
+                              "AND withdrawal_account=:from_acc_id AND deposit_account=:to_acc_id "
+                              "AND withdrawal=:f_amount AND deposit=:t_amount",
+                              [(":timestamp", timestamp), (":from_acc_id", f_acc_id), (":to_acc_id", t_acc_id),
+                               (":f_amount", f_amount), (":t_amount", t_amount)])
         if transfer_id:
             logging.info(g_tr('JalDB', "Transfer/Exchange already exists: ") + f"{f_amount}->{t_amount}")
             return
