@@ -10,8 +10,8 @@ from jal.widgets.delegates import TimestampDelegate, FloatDelegate
 class DealsReportModel(QSqlTableModel):
     def __init__(self, parent_view):
         self._columns = [("asset", g_tr("Reports", "Asset")),
-                         ("open_timestamp", g_tr("Reports", "Open Date")),
-                         ("close_timestamp", g_tr("Reports", "Close Date")),
+                         ("o_datetime", g_tr("Reports", "Open Date")),
+                         ("c_datetime", g_tr("Reports", "Close Date")),
                          ("open_price", g_tr("Reports", "Open Price")),
                          ("close_price", g_tr("Reports", "Close Price")),
                          ("qty", g_tr("Reports", "Qty")),
@@ -68,16 +68,16 @@ class DealsReportModel(QSqlTableModel):
         self._view.horizontalHeader().setFont(font)
         self._view.setColumnWidth(self.fieldIndex("asset"), 300)
         self._view.setColumnWidth(self.fieldIndex("corp_action"), 200)
-        self._view.setColumnWidth(self.fieldIndex("open_timestamp"),
+        self._view.setColumnWidth(self.fieldIndex("o_datetime"),
                                   self._view.fontMetrics().width("00/00/0000 00:00:00") * 1.1)
-        self._view.setColumnWidth(self.fieldIndex("close_timestamp"),
+        self._view.setColumnWidth(self.fieldIndex("c_datetime"),
                                   self._view.fontMetrics().width("00/00/0000 00:00:00") * 1.1)
         if self._group_dates == 1:
             self._timestamp_delegate = TimestampDelegate(display_format='%d/%m/%Y')
         else:
             self._timestamp_delegate = TimestampDelegate()
-        self._view.setItemDelegateForColumn(self.fieldIndex("open_timestamp"), self._timestamp_delegate)
-        self._view.setItemDelegateForColumn(self.fieldIndex("close_timestamp"), self._timestamp_delegate)
+        self._view.setItemDelegateForColumn(self.fieldIndex("o_datetime"), self._timestamp_delegate)
+        self._view.setItemDelegateForColumn(self.fieldIndex("c_datetime"), self._timestamp_delegate)
         self._float_delegate = FloatDelegate(0, allow_tail=True)
         self._view.setItemDelegateForColumn(self.fieldIndex("qty"), self._float_delegate)
         self._float2_delegate = FloatDelegate(2, allow_tail=False)
@@ -95,22 +95,24 @@ class DealsReportModel(QSqlTableModel):
         self._group_dates = group_dates
         if group_dates == 1:
             self._query = executeSQL(
-                               "SELECT asset, "
-                               "strftime('%s', datetime(open_timestamp, 'unixepoch', 'start of day')) as open_timestamp, "
-                               "strftime('%s', datetime(close_timestamp, 'unixepoch', 'start of day')) as close_timestamp, "
-                               "SUM(open_price*qty)/SUM(qty) as open_price, SUM(close_price*qty)/SUM(qty) AS close_price, "
-                               "SUM(qty) as qty, SUM(fee) as fee, SUM(profit) as profit, "
-                               "coalesce(100*SUM(qty*(close_price-open_price)-fee)/SUM(qty*open_price), 0) AS rel_profit "
-                               "FROM deals_ext "
-                               "WHERE account_id=:account_id AND close_timestamp>=:begin AND close_timestamp<=:end "
-                               "GROUP BY asset, open_timestamp, close_timestamp "
-                               "ORDER BY close_timestamp, open_timestamp",
-                               [(":account_id", account_id), (":begin", begin), (":end", end)], forward_only=False)
+                "SELECT asset, "
+                "strftime('%s', datetime(open_timestamp, 'unixepoch', 'start of day')) as o_datetime, "
+                "strftime('%s', datetime(close_timestamp, 'unixepoch', 'start of day')) as c_datetime, "
+                "SUM(open_price*qty)/SUM(qty) as open_price, SUM(close_price*qty)/SUM(qty) AS close_price, "
+                "SUM(qty) as qty, SUM(fee) as fee, SUM(profit) as profit, "
+                "coalesce(100*SUM(qty*(close_price-open_price)-fee)/SUM(qty*open_price), 0) AS rel_profit "
+                "FROM deals_ext "
+                "WHERE account_id=:account_id AND close_timestamp>=:begin AND close_timestamp<=:end "
+                "GROUP BY asset, o_datetime, c_datetime "
+                "ORDER BY c_datetime, o_datetime",
+                [(":account_id", account_id), (":begin", begin), (":end", end)], forward_only=False)
         else:
-            self._query = executeSQL("SELECT asset, open_timestamp, close_timestamp, open_price, close_price, "
-                                    "qty, fee, profit, rel_profit, corp_action FROM deals_ext "
-                                    "WHERE account_id=:account_id AND close_timestamp>=:begin AND close_timestamp<=:end "
-                                    "ORDER BY close_timestamp, open_timestamp",
-                                    [(":account_id", account_id), (":begin", begin), (":end", end)], forward_only=False)
+            self._query = executeSQL(
+                "SELECT asset, open_timestamp AS o_datetime, close_timestamp AS c_datetime, "
+                "open_price, close_price, qty, fee, profit, rel_profit, corp_action "
+                "FROM deals_ext "
+                "WHERE account_id=:account_id AND close_timestamp>=:begin AND close_timestamp<=:end "
+                "ORDER BY c_datetime, o_datetime",
+                [(":account_id", account_id), (":begin", begin), (":end", end)], forward_only=False)
         self.setQuery(self._query)
         self.modelReset.emit()
