@@ -11,9 +11,9 @@ from jal.ui.ui_main_window import Ui_JAL_MainWindow
 from jal.widgets.helpers import g_tr, ManipulateDate, dependency_present
 from jal.widgets.reference_dialogs import AccountTypeListDialog, AccountListDialog, AssetListDialog, TagsListDialog,\
     CategoryListDialog, CountryListDialog, QuotesListDialog, PeerListDialog
-from jal.constants import TransactionType
+from jal.constants import Setup, TransactionType
 from jal.db.backup_restore import JalBackup
-from jal.db.helpers import get_dbfilename
+from jal.db.helpers import get_app_path, get_dbfilename, load_icon
 from jal.db.update import JalDB
 from jal.db.settings import JalSettings
 from jal.data_import.downloader import QuoteDownloader
@@ -30,11 +30,10 @@ from jal.db.tax_estimator import TaxEstimator
 
 #-----------------------------------------------------------------------------------------------------------------------
 class MainWindow(QMainWindow, Ui_JAL_MainWindow):
-    def __init__(self, own_path, language):
+    def __init__(self, language):
         QMainWindow.__init__(self, None)
         self.setupUi(self)
 
-        self.own_path = own_path
         self.currentLanguage = language
         self.current_index = None  # this is used in onOperationContextMenu() to track item for menu
 
@@ -42,7 +41,7 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         self.downloader = QuoteDownloader()
         self.taxes = TaxesRus()
         self.statements = StatementLoader()
-        self.backup = JalBackup(self, get_dbfilename(self.own_path))
+        self.backup = JalBackup(self, get_dbfilename(get_app_path()))
         self.estimator = None
 
         self.actionImportSlipRU.setEnabled(dependency_present(['pyzbar', 'PIL']))
@@ -56,11 +55,16 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         self.statementGroup = QActionGroup(self.menuStatement)
         self.createStatementsImportMenu()
 
+        # Set icons
+        self.NewOperationBtn.setIcon(load_icon("new.png"))
+        self.CopyOperationBtn.setIcon(load_icon("copy.png"))
+        self.DeleteOperationBtn.setIcon(load_icon("delete.png"))
+
         # Operations view context menu
         self.contextMenu = QMenu(self.OperationsTableView)
-        self.actionReconcile = QAction(text=g_tr('MainWindow', "Reconcile"), parent=self)
-        self.actionCopy = QAction(text=g_tr('MainWindow', "Copy"), parent=self)
-        self.actionDelete = QAction(text=g_tr('MainWindow', "Delete"), parent=self)
+        self.actionReconcile = QAction(load_icon("reconcile.png"), g_tr('MainWindow', "Reconcile"), self)
+        self.actionCopy = QAction(load_icon("copy.png"), g_tr('MainWindow', "Copy"), self)
+        self.actionDelete = QAction(load_icon("delete.png"), g_tr('MainWindow', "Delete"), self)
         self.contextMenu.addAction(self.actionReconcile)
         self.contextMenu.addSeparator()
         self.contextMenu.addAction(self.actionCopy)
@@ -166,7 +170,7 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         logging.raiseExceptions = False         # Silencing logging module exceptions
 
     def createLanguageMenu(self):
-        langPath = self.own_path + "languages" + os.sep
+        langPath = get_app_path() + Setup.LANG_PATH + os.sep
 
         langDirectory = QDir(langPath)
         for language_file in langDirectory.entryList(['*.qm']):
@@ -196,7 +200,7 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
     def createStatementsImportMenu(self):
         for i, source in enumerate(self.statements.sources):
             if 'icon' in source:
-                source_icon = QIcon(self.own_path + "img" + os.sep + source['icon'])
+                source_icon = load_icon(source['icon'])
                 action = QAction(source_icon, source['name'], self)
             else:
                 action = QAction(source['name'], self)
@@ -378,4 +382,4 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         elif dlg_type == "quotes":
             QuotesListDialog().exec_()
         else:
-            assert False
\ No newline at end of file
+            assert False
